pub struct Config<T> { /* private fields */ }Expand description
Wrapper around a validated configuration value.
This type ensures that the configuration has been loaded and validated.
It implements Deref to provide transparent access to the inner type.
Implementations
Sourceimpl<T> Config<T>
impl<T> Config<T>
Sourcepub fn new(value: T) -> Self
pub fn new(value: T) -> Self
Create a new Config wrapping an already-validated value.
This is primarily used internally after successful validation.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume this Config and return the inner value.
Sourcepub fn builder() -> ConfigBuilder<T>
pub fn builder() -> ConfigBuilder<T>
Create a builder for this configuration type.